@@ -4,7 +4,9 @@ import yaml
 import os
 import requests
 import shutil
+from trafilatura import fetch_url, extract
 
+# Detect the running OS and return file path delimiter
 def lmt_detect():
     if os.name == 'nt':
         lmt = '\\'
@@ -14,6 +16,7 @@ def lmt_detect():
 
 ROOT_DIR = os.path.abspath(os.curdir)
 
+# Read YAML config file
 def yaml_cred(item_name, cred_path):
     with open(cred_path) as file: 
         documents = yaml.full_load(file)
@@ -22,6 +25,7 @@ def yaml_cred(item_name, cred_path):
               secret_key = doc
               return secret_key
 
+# Download & extract a Google font to local folder
 def get_google_font(font_family):
     lmt = lmt_detect()
     font_url = 'https://fonts.google.com/download?family={}'.format(font_family)
@@ -31,4 +35,14 @@ def get_google_font(font_family):
         f.write(response.content)
     shutil.unpack_archive(file_name, lmt.join([ROOT_DIR, 'font', font_family]))
 
+# Convert a web page content to text file
+def web_to_text(url):
+    downloaded = fetch_url(url)
+    result = extract(downloaded)
+    return result
 
+# Open text file
+def read_txt(path_to_file):
+    with open(path_to_file) as f:
+    content = f.read()
+    return content
